@@ -48,7 +48,7 @@ import org.objectweb.asm.tree.VarInsnNode;
  * A semantic bytecode analyzer. <i>This class does not fully check that JSR and RET instructions
  * are valid.</i>
  *
- * @param <V> type of the Value used for the analysis.
+ * @param <V> type of the {@link Value} used for the analysis.
  * @author Eric Bruneton
  */
 public class Analyzer<V extends Value> implements Opcodes {
@@ -92,7 +92,8 @@ public class Analyzer<V extends Value> implements Opcodes {
   /**
    * Analyzes the given method.
    *
-   * @param owner the internal name of the class to which 'method' belongs.
+   * @param owner the internal name of the class to which 'method' belongs (see {@link
+   *     Type#getInternalName()}).
    * @param method the method to be analyzed. The maxStack and maxLocals fields must have correct
    *     values.
    * @return the symbolic state of the execution stack frame at each bytecode instruction of the
@@ -132,32 +133,8 @@ public class Analyzer<V extends Value> implements Opcodes {
       }
     }
 
-    // For each instruction, compute the subroutine to which it belongs.
-    // Follow the main 'subroutine', and collect the jsr instructions to nested subroutines.
-    Subroutine main = new Subroutine(null, method.maxLocals, null);
-    List<AbstractInsnNode> jsrInsns = new ArrayList<>();
-    findSubroutine(0, main, jsrInsns);
-    // Follow the nested subroutines, and collect their own nested subroutines, until all
-    // subroutines are found.
-    Map<LabelNode, Subroutine> jsrSubroutines = new HashMap<>();
-    while (!jsrInsns.isEmpty()) {
-      JumpInsnNode jsrInsn = (JumpInsnNode) jsrInsns.remove(0);
-      Subroutine subroutine = jsrSubroutines.get(jsrInsn.label);
-      if (subroutine == null) {
-        subroutine = new Subroutine(jsrInsn.label, method.maxLocals, jsrInsn);
-        jsrSubroutines.put(jsrInsn.label, subroutine);
-        findSubroutine(insnList.indexOf(jsrInsn.label), subroutine, jsrInsns);
-      } else {
-        subroutine.callers.add(jsrInsn);
-      }
-    }
-    // Clear the main 'subroutine', which is not a real subroutine (and was used only as an
-    // intermediate step above to find the real ones).
-    for (int i = 0; i < insnListSize; ++i) {
-      if (subroutines[i] != null && subroutines[i].start == null) {
-        subroutines[i] = null;
-      }
-    }
+    // Finds the method's subroutines.
+    findSubroutines(method.maxLocals);
 
     // Initializes the data structures for the control flow analysis.
     Frame<V> currentFrame = computeInitialFrame(owner, method);
@@ -304,7 +281,8 @@ public class Analyzer<V extends Value> implements Opcodes {
    * Analyzes the given method and computes and sets its maximum stack size and maximum number of
    * local variables.
    *
-   * @param owner the internal name of the class to which 'method' belongs.
+   * @param owner the internal name of the class to which 'method' belongs (see {@link
+   *     Type#getInternalName()}).
    * @param method the method to be analyzed.
    * @return the symbolic state of the execution stack frame at each bytecode instruction of the
    *     method. The size of the returned array is equal to the number of instructions (and labels)
@@ -329,6 +307,9 @@ public class Analyzer<V extends Value> implements Opcodes {
    */
   private static int computeMaxLocals(final MethodNode method) {
     int maxLocals = Type.getArgumentsAndReturnSizes(method.desc) >> 2;
+    if ((method.access & Opcodes.ACC_STATIC) != 0) {
+      maxLocals -= 1;
+    }
     for (AbstractInsnNode insnNode : method.instructions) {
       if (insnNode instanceof VarInsnNode) {
         int local = ((VarInsnNode) insnNode).var;
@@ -368,6 +349,42 @@ public class Analyzer<V extends Value> implements Opcodes {
     return maxStack;
   }
 
+  /**
+   * Finds the subroutines of the currently analyzed method and stores them in {@link #subroutines}.
+   *
+   * @param maxLocals the maximum number of local variables of the currently analyzed method (long
+   *     and double values count for two variables).
+   * @throws AnalyzerException if the control flow graph can fall off the end of the code.
+   */
+  private void findSubroutines(final int maxLocals) throws AnalyzerException {
+    // For each instruction, compute the subroutine to which it belongs.
+    // Follow the main 'subroutine', and collect the jsr instructions to nested subroutines.
+    Subroutine main = new Subroutine(null, maxLocals, null);
+    List<AbstractInsnNode> jsrInsns = new ArrayList<>();
+    findSubroutine(0, main, jsrInsns);
+    // Follow the nested subroutines, and collect their own nested subroutines, until all
+    // subroutines are found.
+    Map<LabelNode, Subroutine> jsrSubroutines = new HashMap<>();
+    while (!jsrInsns.isEmpty()) {
+      JumpInsnNode jsrInsn = (JumpInsnNode) jsrInsns.remove(0);
+      Subroutine subroutine = jsrSubroutines.get(jsrInsn.label);
+      if (subroutine == null) {
+        subroutine = new Subroutine(jsrInsn.label, maxLocals, jsrInsn);
+        jsrSubroutines.put(jsrInsn.label, subroutine);
+        findSubroutine(insnList.indexOf(jsrInsn.label), subroutine, jsrInsns);
+      } else {
+        subroutine.callers.add(jsrInsn);
+      }
+    }
+    // Clear the main 'subroutine', which is not a real subroutine (and was used only as an
+    // intermediate step above to find the real ones).
+    for (int i = 0; i < insnListSize; ++i) {
+      if (subroutines[i] != null && subroutines[i].start == null) {
+        subroutines[i] = null;
+      }
+    }
+  }
+
   /**
    * Follows the control flow graph of the currently analyzed method, starting at the given
    * instruction index, and stores a copy of the given subroutine in {@link #subroutines} for each
@@ -453,7 +470,8 @@ public class Analyzer<V extends Value> implements Opcodes {
   /**
    * Computes the initial execution stack frame of the given method.
    *
-   * @param owner the internal name of the class to which 'method' belongs.
+   * @param owner the internal name of the class to which 'method' belongs (see {@link
+   *     Type#getInternalName()}).
    * @param method the method to be analyzed.
    * @return the initial execution stack frame of the 'method'.
    */
@@ -510,9 +528,10 @@ public class Analyzer<V extends Value> implements Opcodes {
 
   /**
    * Initializes this analyzer. This method is called just before the execution of control flow
-   * analysis loop in #analyze. The default implementation of this method does nothing.
+   * analysis loop in {@link #analyze}. The default implementation of this method does nothing.
    *
-   * @param owner the internal name of the class to which the method belongs.
+   * @param owner the internal name of the class to which the method belongs (see {@link
+   *     Type#getInternalName()}).
    * @param method the method to be analyzed.
    * @throws AnalyzerException if a problem occurs.
    */
