@@ -33,6 +33,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTimeoutPreemptively;
 import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.IOException;
 import java.nio.file.Files;
@@ -45,6 +46,7 @@ import org.junit.jupiter.params.provider.MethodSource;
 import org.objectweb.asm.ClassReader;
 import org.objectweb.asm.Opcodes;
 import org.objectweb.asm.test.AsmTest;
+import org.objectweb.asm.test.AsmTest.PrecompiledClass;
 import org.objectweb.asm.tree.ClassNode;
 import org.objectweb.asm.tree.MethodNode;
 
@@ -138,12 +140,32 @@ class AnalyzerWithBasicInterpreterTest extends AsmTest {
       analyzedMethodMaxs.add(new MethodMaxs(methodNode.maxStack, methodNode.maxLocals));
     }
 
+    // jdk3.SubOptimalMaxStackAndLocals has non optimal max stack and max local values on purpose.
+    assumeTrue(classParameter != PrecompiledClass.JDK3_SUB_OPTIMAL_MAX_STACK_AND_LOCALS);
     for (int i = 0; i < analyzedMethodMaxs.size(); ++i) {
       assertTrue(analyzedMethodMaxs.get(i).maxLocals >= methodMaxs.get(i).maxLocals);
       assertTrue(analyzedMethodMaxs.get(i).maxStack >= methodMaxs.get(i).maxStack);
     }
   }
 
+  /**
+   * Tests that analyzeAndComputeMaxs computes the smallest possible maxLocals for static methods.
+   *
+   * @throws AnalyzerException if the test class can't be analyzed.
+   */
+  @Test
+  void testAnalyzeAndComputeMaxs_staticMethod() throws AnalyzerException {
+    MethodNode methodNode =
+        new MethodNodeBuilder("(I)V", /* maxStack = */ 0, /* maxLocals = */ 0).vreturn().build();
+    methodNode.access |= Opcodes.ACC_STATIC;
+    Analyzer<BasicValue> analyzer = new Analyzer<BasicValue>(new BasicInterpreter());
+
+    analyzer.analyzeAndComputeMaxs("C", methodNode);
+
+    assertEquals(1, methodNode.maxLocals);
+    assertEquals(0, methodNode.maxStack);
+  }
+
   /**
    * Tests that the analyzer does not loop infinitely, even if the {@link Interpreter#merge} method
    * does not follow its required contract (namely that if the merge result is equal to the first
