@@ -30,7 +30,6 @@ package org.objectweb.asm.util;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -447,16 +446,26 @@ public class CheckMethodAdapter extends MethodVisitor {
         new MethodNode(api, access, name, descriptor, null, null) {
           @Override
           public void visitEnd() {
-            Analyzer<BasicValue> analyzer = new Analyzer<>(new BasicVerifier());
-            try {
+            int originalMaxLocals = maxLocals;
+            int originalMaxStack = maxStack;
+            boolean checkMaxStackAndLocals = false;
+            boolean checkFrames = false;
+            if (methodVisitor instanceof MethodWriterWrapper) {
+              MethodWriterWrapper methodWriter = (MethodWriterWrapper) methodVisitor;
               // If 'methodVisitor' is a MethodWriter of a ClassWriter with no flags to compute the
               // max stack and locals nor the stack map frames, we know that valid max stack and
               // locals must be provided. Otherwise we assume they are not needed at this stage.
-              // TODO(ebruneton): similarly, check that valid stack map frames are provided if the
-              // class writer has no flags to compute them, and the class version is V1_7 or more.
-              boolean checkMaxStackAndLocals =
-                  (methodVisitor instanceof MethodWriterWrapper)
-                      && !((MethodWriterWrapper) methodVisitor).computesMaxs();
+              checkMaxStackAndLocals = !methodWriter.computesMaxs();
+              // If 'methodVisitor' is a MethodWriter of a ClassWriter with no flags to compute the
+              // stack map frames, we know that valid frames must be provided. Otherwise we assume
+              // they are not needed at this stage.
+              checkFrames = methodWriter.requiresFrames() && !methodWriter.computesFrames();
+            }
+            Analyzer<BasicValue> analyzer =
+                checkFrames
+                    ? new CheckFrameAnalyzer<>(new BasicVerifier())
+                    : new Analyzer<>(new BasicVerifier());
+            try {
               if (checkMaxStackAndLocals) {
                 analyzer.analyze("dummy", this);
               } else {
@@ -466,6 +475,8 @@ public class CheckMethodAdapter extends MethodVisitor {
               throwError(analyzer, e);
             }
             if (methodVisitor != null) {
+              maxLocals = originalMaxLocals;
+              maxStack = originalMaxStack;
               accept(methodVisitor);
             }
           }
@@ -776,9 +787,8 @@ public class CheckMethodAdapter extends MethodVisitor {
     checkVisitCodeCalled();
     checkVisitMaxsNotCalled();
     checkOpcodeMethod(opcode, Method.VISIT_JUMP_INSN);
-    checkLabel(label, false, "label");
+    checkLabel(label, /* checkVisited = */ false, "label");
     super.visitJumpInsn(opcode, label);
-    referencedLabels.add(label);
     ++insnCount;
   }
 
@@ -786,7 +796,7 @@ public class CheckMethodAdapter extends MethodVisitor {
   public void visitLabel(final Label label) {
     checkVisitCodeCalled();
     checkVisitMaxsNotCalled();
-    checkLabel(label, false, "label");
+    checkLabel(label, /* checkVisited = */ false, "label");
     if (labelInsnIndices.get(label) != null) {
       throw new IllegalStateException("Already visited label");
     }
@@ -822,15 +832,14 @@ public class CheckMethodAdapter extends MethodVisitor {
       throw new IllegalArgumentException(
           "Max = " + max + " must be greater than or equal to min = " + min);
     }
-    checkLabel(dflt, false, "default label");
+    checkLabel(dflt, /* checkVisited = */ false, "default label");
     if (labels == null || labels.length != max - min + 1) {
       throw new IllegalArgumentException("There must be max - min + 1 labels");
     }
     for (int i = 0; i < labels.length; ++i) {
-      checkLabel(labels[i], false, "label at index " + i);
+      checkLabel(labels[i], /* checkVisited = */ false, "label at index " + i);
     }
     super.visitTableSwitchInsn(min, max, dflt, labels);
-    Collections.addAll(referencedLabels, labels);
     ++insnCount;
   }
 
@@ -838,16 +847,14 @@ public class CheckMethodAdapter extends MethodVisitor {
   public void visitLookupSwitchInsn(final Label dflt, final int[] keys, final Label[] labels) {
     checkVisitMaxsNotCalled();
     checkVisitCodeCalled();
-    checkLabel(dflt, false, "default label");
+    checkLabel(dflt, /* checkVisited = */ false, "default label");
     if (keys == null || labels == null || keys.length != labels.length) {
       throw new IllegalArgumentException("There must be the same number of keys and labels");
     }
     for (int i = 0; i < labels.length; ++i) {
-      checkLabel(labels[i], false, "label at index " + i);
+      checkLabel(labels[i], /* checkVisited = */ false, "label at index " + i);
     }
     super.visitLookupSwitchInsn(dflt, keys, labels);
-    referencedLabels.add(dflt);
-    Collections.addAll(referencedLabels, labels);
     ++insnCount;
   }
 
@@ -901,9 +908,9 @@ public class CheckMethodAdapter extends MethodVisitor {
       final Label start, final Label end, final Label handler, final String type) {
     checkVisitCodeCalled();
     checkVisitMaxsNotCalled();
-    checkLabel(start, false, START_LABEL);
-    checkLabel(end, false, END_LABEL);
-    checkLabel(handler, false, "handler label");
+    checkLabel(start, /* checkVisited = */ false, START_LABEL);
+    checkLabel(end, /* checkVisited = */ false, END_LABEL);
+    checkLabel(handler, /* checkVisited = */ false, "handler label");
     if (labelInsnIndices.get(start) != null
         || labelInsnIndices.get(end) != null
         || labelInsnIndices.get(handler) != null) {
@@ -947,8 +954,8 @@ public class CheckMethodAdapter extends MethodVisitor {
     if (signature != null) {
       CheckClassAdapter.checkFieldSignature(signature);
     }
-    checkLabel(start, true, START_LABEL);
-    checkLabel(end, true, END_LABEL);
+    checkLabel(start, /* checkVisited = */ true, START_LABEL);
+    checkLabel(end, /* checkVisited = */ true, END_LABEL);
     checkUnsignedShort(index, INVALID_LOCAL_VARIABLE_INDEX);
     int startInsnIndex = labelInsnIndices.get(start).intValue();
     int endInsnIndex = labelInsnIndices.get(end).intValue();
@@ -985,8 +992,8 @@ public class CheckMethodAdapter extends MethodVisitor {
           "Invalid start, end and index arrays (must be non null and of identical length");
     }
     for (int i = 0; i < start.length; ++i) {
-      checkLabel(start[i], true, START_LABEL);
-      checkLabel(end[i], true, END_LABEL);
+      checkLabel(start[i], /* checkVisited = */ true, START_LABEL);
+      checkLabel(end[i], /* checkVisited = */ true, END_LABEL);
       checkUnsignedShort(index[i], INVALID_LOCAL_VARIABLE_INDEX);
       int startInsnIndex = labelInsnIndices.get(start[i]).intValue();
       int endInsnIndex = labelInsnIndices.get(end[i]).intValue();
@@ -1004,7 +1011,7 @@ public class CheckMethodAdapter extends MethodVisitor {
     checkVisitCodeCalled();
     checkVisitMaxsNotCalled();
     checkUnsignedShort(line, "Invalid line number");
-    checkLabel(start, true, START_LABEL);
+    checkLabel(start, /* checkVisited = */ true, START_LABEL);
     super.visitLineNumber(line, start);
   }
 
@@ -1021,11 +1028,8 @@ public class CheckMethodAdapter extends MethodVisitor {
     for (int i = 0; i < handlers.size(); i += 2) {
       Integer startInsnIndex = labelInsnIndices.get(handlers.get(i));
       Integer endInsnIndex = labelInsnIndices.get(handlers.get(i + 1));
-      if (startInsnIndex == null || endInsnIndex == null) {
-        throw new IllegalStateException("Undefined try catch block labels");
-      }
       if (endInsnIndex.intValue() <= startInsnIndex.intValue()) {
-        throw new IllegalStateException("Emty try catch block handler range");
+        throw new IllegalStateException("Empty try catch block handler range");
       }
     }
     checkUnsignedShort(maxStack, "Invalid max stack");
@@ -1084,7 +1088,7 @@ public class CheckMethodAdapter extends MethodVisitor {
     if (value instanceof String) {
       checkInternalName(version, (String) value, "Invalid stack frame value");
     } else if (value instanceof Label) {
-      referencedLabels.add((Label) value);
+      checkLabel((Label) value, /* checkVisited = */ false, "label");
     } else {
       throw new IllegalArgumentException("Invalid stack frame value: " + value);
     }
@@ -1444,19 +1448,36 @@ public class CheckMethodAdapter extends MethodVisitor {
     if (checkVisited && labelInsnIndices.get(label) == null) {
       throw new IllegalArgumentException(INVALID + message + " (must be visited first)");
     }
+    referencedLabels.add(label);
   }
 
   static class MethodWriterWrapper extends MethodVisitor {
 
+    /** The class version number. */
+    private final int version;
+
     private final ClassWriter owner;
 
-    MethodWriterWrapper(final int api, final ClassWriter owner, final MethodVisitor methodWriter) {
+    MethodWriterWrapper(
+        final int api,
+        final int version,
+        final ClassWriter owner,
+        final MethodVisitor methodWriter) {
       super(api, methodWriter);
+      this.version = version;
       this.owner = owner;
     }
 
     boolean computesMaxs() {
       return owner.hasFlags(ClassWriter.COMPUTE_MAXS) || owner.hasFlags(ClassWriter.COMPUTE_FRAMES);
     }
+
+    boolean computesFrames() {
+      return owner.hasFlags(ClassWriter.COMPUTE_FRAMES);
+    }
+
+    boolean requiresFrames() {
+      return (version & 0xFFFF) >= Opcodes.V1_7;
+    }
   }
 }
